# PyService

![build](https://github.com/adomokos/pyservice/workflows/Python%20Build/badge.svg)

A [light-service](https://github.com/adomokos/light-service) influenced project in Python.

More info and code samples coming later.
